@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "buffer-terminator" "1.2.0"
+(define-package "buffer-terminator" "20250911.2238"
   "Safely Terminate/Kill Buffers Automatically."
   '((emacs "25.1"))
   :url "https://github.com/jamescherti/buffer-terminator.el"
-  :commit "28def905e7d01fb24369b104e1bd1d7bdac8811c"
-  :revdesc "1.2.0-0-g28def905e7d0"
+  :commit "68552751bcfd049e72a5b81b3077b121ec7a7d01"
+  :revdesc "68552751bcfd"
   :keywords '("convenience"))
